@@ -19,7 +19,7 @@ sites = [
 ]
 
 
-class Virus:
+class Virus():
     def open_website(self, duration):
         t = 0
         while t <= duration:
